@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Measure the positive/negative sentiment of text
 
-our $VERSION = '0.0101';
+our $VERSION = '0.02';
 
 use Moo;
 use strictures 2;
@@ -22,6 +22,11 @@ has file => (
 );
 
 
+has text => (
+      is  => 'ro',
+);
+
+
 has sentences => (
     is       => 'rw',
     init_arg => undef,
@@ -37,7 +42,7 @@ has scores => (
 sub analyze {
     my ($self) = @_;
 
-    my $contents = read_text( $self->file );
+    my $contents = $self->file ? read_text( $self->file ) : $self->text;
 
     $self->sentences( get_sentences($contents) );
 
@@ -80,7 +85,7 @@ Lingua::EN::Opinion - Measure the positive/negative sentiment of text
 
 =head1 VERSION
 
-version 0.0101
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -102,6 +107,10 @@ Please see the F<eg/> and F<t/> scripts for example usage.
 
 The text file to analyze.
 
+=head2 text
+
+A text string to analyze instead of a text file.
+
 =head2 sentences
 
 Computed result.
